@@ -19,11 +19,33 @@ from collections import deque, namedtuple
 from copy import deepcopy
 
 __all__ = [
-    'IntegerField', 'BigIntegerField', 'PrimaryKeyField', 'FloatField', 'DoubleField',
-    'DecimalField', 'CharField', 'TextField', 'DateTimeField', 'DateField', 'TimeField',
-    'BooleanField', 'ForeignKeyField', 'Model', 'DoesNotExist', 'ImproperlyConfigured',
-    'DQ', 'fn', 'SqliteDatabase', 'MySQLDatabase', 'PostgresqlDatabase', 'Field',
-    'JOIN_LEFT_OUTER', 'JOIN_INNER', 'JOIN_FULL', 'prefetch',
+    'BigIntegerField',
+    'BlobField',
+    'BooleanField',
+    'CharField',
+    'DateField',
+    'DateTimeField',
+    'DecimalField',
+    'DoesNotExist',
+    'DoubleField',
+    'DQ',
+    'Field',
+    'FloatField',
+    'fn',
+    'ForeignKeyField',
+    'ImproperlyConfigured',
+    'IntegerField',
+    'JOIN_FULL',
+    'JOIN_INNER',
+    'JOIN_LEFT_OUTER',
+    'Model',
+    'MySQLDatabase',
+    'PostgresqlDatabase',
+    'prefetch',
+    'PrimaryKeyField',
+    'SqliteDatabase',
+    'TextField',
+    'TimeField',
 ]
 
 # Python 2/3 compat
@@ -40,9 +62,11 @@ if PY3:
     string_type = bytes
     basestring = str
     print_ = getattr(builtins, 'print')
+    binary_construct = lambda s: bytes(s.encode('raw_unicode_escape'))
 else:
     unicode_type = unicode
     string_type = basestring
+    binary_construct = buffer
     def print_(s):
         sys.stdout.write(s)
         sys.stdout.write('\n')
@@ -357,7 +381,7 @@ class Field(Leaf):
         return value if value is None else self.coerce(value)
 
     def __hash__(self):
-        return hash('.'.join((self.name, self.model_class.__name__)))
+        return hash(self.name + '.' + self.model_class.__name__)
 
 
 class IntegerField(Field):
@@ -436,6 +460,14 @@ class TextField(Field):
     def coerce(self, value):
         return format_unicode(value or '')
 
+class BlobField(Field):
+    db_field = 'blob'
+
+    def db_value(self, value):
+        if isinstance(value, basestring):
+            return binary_construct(value)
+        return value
+
 def format_date_time(value, formats, post_process=None):
     post_process = post_process or (lambda x: x)
     for fmt in formats:
@@ -615,18 +647,19 @@ class ForeignKeyField(IntegerField):
 
 class QueryCompiler(object):
     field_map = {
-        'int': 'INTEGER',
         'bigint': 'INTEGER',
-        'float': 'REAL',
-        'double': 'REAL',
+        'blob': 'BLOB',
+        'bool': 'SMALLINT',
+        'date': 'DATE',
+        'datetime': 'DATETIME',
         'decimal': 'DECIMAL',
+        'double': 'REAL',
+        'float': 'REAL',
+        'int': 'INTEGER',
+        'primary_key': 'INTEGER',
         'string': 'VARCHAR',
         'text': 'TEXT',
-        'datetime': 'DATETIME',
-        'date': 'DATE',
         'time': 'TIME',
-        'bool': 'SMALLINT',
-        'primary_key': 'INTEGER',
     }
 
     op_map = {
@@ -1737,9 +1770,9 @@ class Database(object):
     def sequence_exists(self, seq):
         raise NotImplementedError
 
-    def create_table(self, model_class):
+    def create_table(self, model_class, safe=False):
         qc = self.compiler()
-        return self.execute_sql(qc.create_table(model_class))
+        return self.execute_sql(qc.create_table(model_class, safe))
 
     def create_index(self, model_class, fields, unique=False):
         qc = self.compiler()
@@ -1785,7 +1818,7 @@ class SqliteDatabase(Database):
         return rows
 
     def get_tables(self):
-        res = self.execute_sql('select name from sqlite_master where type="table" order by name')
+        res = self.execute_sql('select name from sqlite_master where type="table" order by name;')
         return [r[0] for r in res.fetchall()]
 
 
@@ -1793,6 +1826,7 @@ class PostgresqlDatabase(Database):
     commit_select = True
     field_overrides = {
         'bigint': 'BIGINT',
+        'blob': 'BYTEA',
         'bool': 'BOOLEAN',
         'datetime': 'TIMESTAMP',
         'decimal': 'NUMERIC',
