@@ -41,8 +41,12 @@ class QueryLogHandler(logging.Handler):
 if sys.version_info[0] < 3:
     import codecs
     ulit = lambda s: codecs.unicode_escape_decode(s)[0]
+    binary_construct = buffer
+    binary_types = buffer
 else:
     ulit = lambda s: s
+    binary_construct = lambda s: bytes(s.encode('raw_unicode_escape'))
+    binary_types = (bytes, memoryview)
 
 #
 # JUNK TO ALLOW TESTING OF MULTIPLE DATABASE BACKENDS
@@ -250,10 +254,13 @@ class CSVField(TextField):
 class CSVRow(TestModel):
     data = CSVField()
 
+class BlobModel(TestModel):
+    data = BlobField()
+
 
 MODELS = [User, Blog, Comment, Relationship, NullModel, UniqueModel, OrderedModel, Category, UserCategory,
           NonIntModel, NonIntRelModel, DBUser, DBBlog, SeqModelA, SeqModelB, MultiIndexModel, BlogTwo,
-         Parent, Child, Orphan, ChildPet, OrphanPet]
+         Parent, Child, Orphan, ChildPet, OrphanPet, BlobModel]
 INT = test_db.interpolation
 
 def drop_tables(only=None):
@@ -1169,6 +1176,8 @@ class ModelQueryTestCase(ModelTestCase):
         uq.execute()
         self.assertEqual([u.username for u in User.select().order_by(User.id)], ['u-edited', 'u-edited', 'u-edited', 'u4', 'u5'])
 
+        self.assertRaises(KeyError, User.update, doesnotexist='invalid')
+
     def test_insert(self):
         iq = User.insert(username='u1')
         self.assertEqual(User.select().count(), 0)
@@ -1178,6 +1187,8 @@ class ModelQueryTestCase(ModelTestCase):
         u = User.get(User.id==uid)
         self.assertEqual(u.username, 'u1')
 
+        self.assertRaises(KeyError, User.insert, doesnotexist='invalid')
+
     def test_delete(self):
         self.create_users(5)
         dq = User.delete().where(User.username << ['u1', 'u2', 'u3'])
@@ -1796,7 +1807,7 @@ class ManyToManyTestCase(ModelTestCase):
 
 
 class FieldTypeTestCase(ModelTestCase):
-    requires = [NullModel]
+    requires = [NullModel, BlobModel]
 
     _dt = datetime.datetime
     _d = datetime.date
@@ -1999,6 +2010,29 @@ class FieldTypeTestCase(ModelTestCase):
             23, 11
         ))
 
+    def test_blob_field(self):
+        byte_count = 256
+        data = ''.join(chr(i) for i in range(256))
+        blob = BlobModel.create(data=data)
+
+        # pull from db and check binary data
+        res = BlobModel.get(BlobModel.id == blob.id)
+        self.assertTrue(isinstance(res.data, binary_types))
+
+        self.assertEqual(len(res.data), byte_count)
+        self.assertEqual(res.data, binary_construct(data))
+
+        # try querying the blob field
+        binary_data = res.data
+
+        # use the string representation
+        res = BlobModel.get(BlobModel.data == data)
+        self.assertEqual(res.id, blob.id)
+
+        # use the binary representation
+        res = BlobModel.get(BlobModel.data == binary_data)
+        self.assertEqual(res.id, blob.id)
+
 
 class UniqueTestCase(ModelTestCase):
     requires = [UniqueModel, MultiIndexModel]
